#!/bin/sh -e
# linux/scripts/buildmake.sh
#
# Copyright (C) 2001 Russell King
#
# Generate object lists and build information for Makefile.man
#

# top_dirs is a list of directories that we scan for
# Makefile.in files.
top_dirs="init kernel mm fs ipc drivers net arch/${ARCH} lib"

# If the source directory contains a "3rdparty" directory,
# then include it in our search for Makefile.in files.
if [ -d "${srctree}/3rdparty" ]; then
  ${top_dirs}="${top_dirs} 3rdparty"
fi

echo -n "Building makefiles"

cd ${srctree}

# Check to see if any Makefile.in files are newer than
# our build information
if [ -f "${LISTS}" ]; then
  newer=`find $top_dirs -name Makefile.in -newer ${LISTS}`
  [ "$newer" = "" ] && echo "... up to date" && exit 0
fi

# Ok, we need to re-generate our build information.
# Find all Makefile.in files.
makefiles=`find $top_dirs -name Makefile.in`

{
  dirs=
  for f in $makefiles; do
    echo -n . >&3
    dir=`dirname $f`
    dirs="$dirs $dir"
    base=`echo $dir | sed s,/,_,g`
    echo "# --------------------- $f -----------------------"
    sed -f ${scriptdir}/mkbuild -e "s,@DIR@,$dir,g" -e "s,@BASE@,$base,g" $f
    echo "obj_m += \$(obj_${base}_m)"
  done
  echo -e "dirs += $dirs"
} 3>&1 > ${LISTS}.tmp
mv -f ${LISTS}.tmp ${LISTS}
echo " done"
